/*
 *  Copyright (C) 2004-2005 Mathias Andre <mathias.andre@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include "nb_attachment.h"

#include <libgnomevfs/gnome-vfs.h>

static void
nb_attachment_instance_init (GTypeInstance * instance, gpointer g_class)
{
	NbAttachment * self = (NbAttachment *) instance;
	self->uri = NULL;
	self->mime_type = NULL;
	self->dispose_has_run = FALSE;
}

static void
nb_attachment_dispose (GObject * obj)
{
	NbAttachment * self = (NbAttachment *) obj;

	if ( self->dispose_has_run ) {
		/* If dispose did already run, return. */
		return;
	}

	/* Make sure dispose does not run twice. */
	self->dispose_has_run = TRUE;
}

static void
nb_attachment_finalize (GObject * obj)
{
	NbAttachment * self = (NbAttachment *) obj;

	/* complete object destruction. */
	g_free (self->uri);
	g_free (self->mime_type);
}

static void
nb_attachment_class_init (gpointer g_class, gpointer g_class_data)
{
	GObjectClass * gobject_class = G_OBJECT_CLASS (g_class);

	gobject_class->dispose = nb_attachment_dispose;
	gobject_class->finalize = nb_attachment_finalize;
}


GType
nb_attachment_get_type (void)
{
	static GType type = 0;
	if ( type == 0 )
       	{
		static const GTypeInfo info = {
			sizeof (NbAttachmentClass),
			NULL,   /* base_init */
			NULL,   /* base_finalize */
			nb_attachment_class_init,   /* class_init */
			NULL,   /* class_finalize */
			NULL,   /* class_data */
			sizeof (NbAttachment),
			0,      /* n_preallocs */
			nb_attachment_instance_init    /* instance_init */
		};
		type = g_type_register_static (G_TYPE_OBJECT,
				"NbAttachmentType",
				&info, 0);
	}
	return type;
}

NbAttachment *
nb_attachment_new (gchar * uri, gchar * mime_type)
{
	NbAttachment * self = NB_ATTACHMENT (g_object_new (NB_TYPE_ATTACHMENT, NULL));
	self->uri = uri;
	self->mime_type = mime_type;

	return self;
}

/* methods */
gboolean
nb_attachment_check (NbAttachment * self)
{
	GnomeVFSURI * uri = gnome_vfs_uri_new (self->uri);

	if ( gnome_vfs_uri_exists (uri) )
		return TRUE;
	else
		return FALSE;
}

