/*
 *  Copyright (C) 2004-2005 Mathias Andre <mathias.andre@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef NB_INTERFACE_H
#define NB_INTERFACE_H

#include <glib-object.h>
#include <glade/glade.h>

#include "nb_treeview.h"
#include "nb_noteview.h"

#define NB_TYPE_INTERFACE           (nb_interface_get_type ())
#define NB_INTERFACE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), NB_TYPE_INTERFACE, NbInterface))
#define NB_INTERFACE_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), NB_TYPE_INTERFACE, NbInterfaceClass))
#define NB_IS_INTERFACE(obj)        (G_TYPE_CHECK_TYPE ((obj), NB_TYPE_INTERFACE))
#define NB_IS_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NB_TYPE_INTERFACE))
#define NB_INTERFACE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NB_TYPE_INTERFACE, NbInterfaceClass))

typedef struct _NbInterface NbInterface;
typedef struct _NbInterfaceClass NbInterfaceClass;

struct _NbInterface 
{
	GObject parent;

	/* instance members */
	GladeXML * main_xml;
	NbTreeview * treeview;
	NbNoteview * noteview;
	GtkWidget * main_window;
	GtkWidget * search_entry;
	gboolean dispose_has_run;
};

struct _NbInterfaceClass
{
	GObjectClass parent;

	/* class members */
};

GType nb_interface_get_type (void);

NbInterface *		nb_interface_new (void);

/* methods */

/* callbacks */
void			nb_interface_cb_new_note (GtkWidget * widget, gpointer userdata);
void			nb_interface_cb_delete_note (GtkWidget * widget, gpointer userdata);
gboolean		nb_interface_cb_quit (GtkWidget * widget, gpointer userdata);
void			nb_interface_cb_search_edited (GtkWidget * widget, gpointer userdata);
void			nb_interface_cb_search_cleared (GtkWidget * widget, gpointer userdata);
void			nb_interface_cb_about_dialog (GtkWidget * widget, gpointer userdata);

/* drag and drop callbacks */
void			nb_ui_cb_drag_received (GtkWidget * widget, GdkDragContext * context, int x, int y, GtkSelectionData * seldata, guint info, guint time, gpointer userdata);
#endif
