/*
 *  Copyright (C) 2004-2005 Mathias Andre <mathias.andre@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef NB_NOTE_H
#define NB_NOTE_H

#include <glib-object.h>
#include <libxml/tree.h>

#include "nb_attachment.h"

#define NB_TYPE_NOTE           (nb_note_get_type ())
#define NB_NOTE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), NB_TYPE_NOTE, NbNote))
#define NB_NOTE_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), NB_TYPE_NOTE, NbNoteClass))
#define NB_IS_NOTE(obj)        (G_TYPE_CHECK_TYPE ((obj), NB_TYPE_NOTE))
#define NB_IS_NOTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NB_TYPE_NOTE))
#define NB_NOTE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NB_TYPE_NOTE, NbNoteClass))

typedef struct _NbNote NbNote;
typedef struct _NbNoteClass NbNoteClass;

struct _NbNote 
{
	GObject parent;

	/* instance members */
	gchar * title;
	gchar * text;
	GTime creation_date;
	GTime last_update;
	GPtrArray * attachments;	
	gchar * type;
	GtkTreeIter * iter;
	gboolean dispose_has_run;
};

struct _NbNoteClass
{
	GObjectClass parent;

	/* class members */
};

GType nb_note_get_type (void);

NbNote * 	nb_note_new (void);

/* methods */

/* update attributes */
void            nb_note_set_title (NbNote * self, gchar * title);
void            nb_note_set_text (NbNote * self, gchar * text);
void            nb_note_set_type (NbNote * self, gchar * type);
void		nb_note_set_creation_date (NbNote * self);
void		nb_note_set_last_update (NbNote * self);
void            nb_note_clear_text (NbNote * self);

gchar *		nb_note_get_utf_title (NbNote * self);
gchar *		nb_note_get_utf_type (NbNote * self);
gchar *		nb_note_get_utf_creation_date (NbNote * self);
gchar *		nb_note_get_utf_last_update (NbNote * self);
gchar *		nb_note_get_utf_text (NbNote * self);

/* attachments */
void		nb_note_add_attachment (NbNote * self, NbAttachment * attachment);
void	        nb_note_remove_attachment (NbNote * self, NbAttachment * attachment);
gint            nb_note_get_nb_attachments (NbNote * self);
void            nb_note_check_attachments (NbNote * self);

xmlNodePtr	nb_note_get_xml_pointer (NbNote * self, gint index);
void		nb_note_load_text (NbNote * self, xmlDocPtr doc, xmlNodePtr cur);
NbNote *	nb_note_new_from_xml_doc (xmlDocPtr doc, xmlNodePtr cur);


/* queries */
gboolean        nb_note_matches_query (NbNote * self, gchar * query);

#endif
