/*
 *  Copyright (C) 2004-2005 Mathias Andre <mathias.andre@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef NB_NOTEBOOK_H
#define NB_NOTEBOOK_H

#include <glib-object.h>
#include <gtk/gtk.h>

#include "nb_interface.h"
#include "nb_note.h"

#define NB_TYPE_NOTEBOOK           (nb_notebook_get_type ())
#define NB_NOTEBOOK(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), NB_TYPE_NOTEBOOK, NbNotebook))
#define NB_NOTEBOOK_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), NB_TYPE_NOTEBOOK, NbNotebookClass))
#define NB_IS_NOTEBOOK(obj)        (G_TYPE_CHECK_TYPE ((obj), NB_TYPE_NOTEBOOK))
#define NB_IS_NOTEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NB_TYPE_NOTEBOOK))
#define NB_NOTEBOOK_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NB_TYPE_NOTEBOOK, NbNotebookClass))

typedef enum
{
	ADD_NOTE,
	REMOVE_NOTE,
	UPDATE_NOTE,
} NbXmlAction;

typedef struct _NbNoteType NbNoteType;

struct _NbNoteType
{
	gchar * name;
	gint nb;
};

typedef struct _NbNotebook NbNotebook;
typedef struct _NbNotebookClass NbNotebookClass;

struct _NbNotebook 
{
	GObject parent;

	/* instance members */
	NbNote * current_note;
	NbNote * last_selected_note;
	gint dragged_row_index;
	NbInterface * ui;
	gboolean note_is_inserted;
	gboolean note_is_modified;
	gboolean note_edited_lock;
	GPtrArray * notes;
	GPtrArray * note_types;
	GtkListStore * store;
	gchar * filename;

	gboolean dispose_has_run;
};

struct _NbNotebookClass
{
	GObjectClass parent;

	/* class members */
};

GType nb_notebook_get_type (void);

NbNotebook * 		nb_notebook_new (void);

/* methods */
void			nb_notebook_quit (NbNotebook * self);
void			nb_notebook_new_note (NbNotebook * self);
void 			nb_notebook_load_xml_file (NbNotebook * self);
void			nb_notebook_delete_note (NbNotebook * self);
void			nb_notebook_save_note (NbNotebook * self);
gint			nb_notebook_get_nb_notes (NbNotebook * self);
void			nb_notebook_add_note_type (NbNotebook * self, gchar * type);
void			nb_notebook_remove_note_type (NbNotebook * self, gchar * ctype);
gint			nb_notebook_get_note_type_index (NbNotebook * self, gchar * ctype);
void			nb_notebook_load_note_text (NbNotebook * self, NbNote * note);
gint 			nb_notebook_get_note_index (NbNotebook * self, NbNote * note);

void			nb_notebook_update_xml_file (NbNotebook * self, NbXmlAction action);

#endif
