/*
 *  Copyright (C) 2004-2005 Mathias Andre <mathias.andre@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include <libgnomeui/libgnomeui.h>
#include <string.h>

#include "nb_noteview.h"
#include "nb_notebook.h"
#include "nb_interface.h"

static void	nb_noteview_set_tag_at_coord (NbNoteview * self, GtkTextTag * tag, gint x, gint y);
static gboolean nb_noteview_cb_drag_drop (GtkWidget * widget, GdkDragContext * context, gint x, gint y, guint time, gpointer user_data);

static void
nb_noteview_instance_init (GTypeInstance * instance, gpointer g_class)
{
	NbNoteview * self = (NbNoteview *) instance;
	self->dispose_has_run = FALSE;
}

static void
nb_noteview_dispose (GObject * obj)
{
	NbNoteview * self = (NbNoteview *) obj;

	if ( self->dispose_has_run ) {
		/* If dispose did already run, return. */
		return;
	}

	/* Make sure dispose does not run twice. */
	self->dispose_has_run = TRUE;
}

static void
nb_noteview_finalize (GObject * obj)
{
	NbNoteview * self = (NbNoteview *) obj;

	/* complete object destruction. */
}

static void
nb_noteview_class_init (gpointer g_class, gpointer g_class_data)
{
	GObjectClass * gobject_class = G_OBJECT_CLASS (g_class);

	gobject_class->dispose = nb_noteview_dispose;
	gobject_class->finalize = nb_noteview_finalize;
}


GType
nb_noteview_get_type (void)
{
	static GType type = 0;
	if ( type == 0 )
       	{
		static const GTypeInfo info = {
			sizeof (NbNoteviewClass),
			NULL,   /* base_init */
			NULL,   /* base_finalize */
			nb_noteview_class_init,   /* class_init */
			NULL,   /* class_finalize */
			NULL,   /* class_data */
			sizeof (NbNoteview),
			0,      /* n_preallocs */
			nb_noteview_instance_init    /* instance_init */
		};
		type = g_type_register_static (G_TYPE_OBJECT,
				"NbNoteviewType",
				&info, 0);
	}
	return type;
}

NbNoteview *
nb_noteview_new (GObject * interface)
{
	NbNoteview * self = NB_NOTEVIEW (g_object_new (NB_TYPE_NOTEVIEW, NULL));
	extern NbNotebook * notebook;
	NbInterface * ui = NB_INTERFACE (interface);
	GtkWidget * hbox;

	self->textview = glade_xml_get_widget (ui->main_xml, "textview");
	self->subject = glade_xml_get_widget (ui->main_xml, "entry_subject");
	hbox = glade_xml_get_widget (ui->main_xml, "hbox8");
	self->type = gtk_combo_box_entry_new_text ();
	gtk_box_pack_end (GTK_BOX (hbox), self->type, FALSE, FALSE, 6);
	gtk_widget_show (self->type);
	self->date = glade_xml_get_widget (ui->main_xml, "label_date_value");
	GtkTextBuffer * buffer = gtk_text_view_get_buffer ( GTK_TEXT_VIEW (self->textview) );

	gtk_text_buffer_set_text (buffer, "", 15);
	gtk_text_view_set_buffer ( GTK_TEXT_VIEW (self->textview) , buffer);

	self->note_link = gtk_text_buffer_create_tag (buffer, "note_link",
			"foreground", "red", NULL);

	g_signal_connect (G_OBJECT (self->type), "changed", G_CALLBACK (nb_noteview_cb_edited), NULL);
	g_signal_connect (G_OBJECT (buffer), "changed", G_CALLBACK (nb_noteview_cb_edited), NULL);
	g_signal_connect (G_OBJECT (self->textview), "drag-drop", G_CALLBACK (nb_noteview_cb_drag_drop), NULL);

	/* Drag and Drop */
	gtk_drag_dest_set (self->textview,
			GTK_DEST_DEFAULT_DROP | GTK_DEST_DEFAULT_HIGHLIGHT,
			target_list,
			1,
			GDK_ACTION_LINK);

	return self;
}

/* methods */
gchar *
nb_noteview_get_title (NbNoteview * self)
{
	return gtk_editable_get_chars (GTK_EDITABLE (self->subject), 0, -1 );
}

gchar *
nb_noteview_get_text (NbNoteview * self)
{
	GtkTextIter start;
	GtkTextIter end;
	GtkTextBuffer * buffer =  gtk_text_view_get_buffer ( GTK_TEXT_VIEW (self->textview) );

	gtk_text_buffer_get_start_iter (buffer, &start);
	gtk_text_buffer_get_end_iter (buffer, &end);


	return gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
}

gchar *
nb_noteview_get_type_from_combo (NbNoteview * self)
{
	return gtk_combo_box_get_active_text (GTK_COMBO_BOX (self->type));
}

gboolean
nb_noteview_is_empty (NbNoteview * self)
{
	GtkTextIter start;
	GtkTextIter end;

	GtkTextBuffer * buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->textview) );
	gtk_text_buffer_get_start_iter (buffer, &start);
	gtk_text_buffer_get_end_iter (buffer, &end);

	if ( (strlen (gtk_entry_get_text (GTK_ENTRY (self->subject) )) == 0) &&
			(strlen (gtk_text_buffer_get_text (buffer, &start, &end, TRUE)) == 0) )
		return TRUE;
	else
		return FALSE;

}

void
nb_noteview_set_fields (NbNoteview * self, NbNote * note)
{
	extern NbNotebook * notebook;
	gchar * title, * type, * creation_date, * text;
	GtkTextIter start, end;
	GtkTextBuffer * buffer;
	
	title = nb_note_get_utf_title (note);
	type = nb_note_get_utf_type (note);
	creation_date = nb_note_get_utf_creation_date (note);
	text = nb_note_get_utf_text (note);

	/* set the title entry */
	gtk_entry_set_text (GTK_ENTRY (self->subject), title);

	/* set the text field */
	buffer =  gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->textview));
	gtk_text_buffer_get_start_iter (buffer, &start);
	gtk_text_buffer_get_end_iter (buffer, &end);
	gtk_text_buffer_delete (buffer, &start, &end);
	gtk_text_buffer_set_text (buffer, text, strlen (text));

	/* TODO: scan text for urls */

	/* set the date label */
	gtk_label_set_label (GTK_LABEL (self->date), creation_date);

	gtk_combo_box_set_active (GTK_COMBO_BOX (self->type), nb_notebook_get_note_type_index (notebook, note->type));

	g_free (title);
	g_free (type);
	g_free (creation_date);
	g_free (text);
}

void
nb_noteview_add_combo_entry (NbNoteview * self, gchar * entry)
{
	gtk_combo_box_append_text (GTK_COMBO_BOX (self->type), entry);
}

void
nb_noteview_remove_combo_entry (NbNoteview * self, gint index)
{
	gtk_combo_box_remove_text (GTK_COMBO_BOX (self->type), index);
}

/* callbacks */
void
nb_noteview_cb_edited (GtkWidget * widget, gpointer user_data)
{
	extern NbNotebook * notebook;

	if ( notebook->note_edited_lock )
		return ;

	GtkTextBuffer * buffer = gtk_text_view_get_buffer ( GTK_TEXT_VIEW (notebook->ui->noteview->textview) );

	if ( nb_notebook_get_nb_notes (notebook) == 0 )
		nb_notebook_new_note (notebook);

	notebook->note_is_modified = TRUE;

	if ( widget == notebook->ui->noteview->subject )
	{
		nb_note_set_title (notebook->current_note, nb_noteview_get_title (notebook->ui->noteview));
	}

	if ( widget == notebook->ui->noteview->type )
	{
		nb_note_set_type (notebook->current_note, nb_noteview_get_type_from_combo (notebook->ui->noteview));
	}

	if ( widget == (GtkWidget *) buffer )
	{
		nb_note_set_text (notebook->current_note, nb_noteview_get_text (notebook->ui->noteview));
	}

	nb_treeview_update_note (notebook->ui->treeview, notebook->current_note);
}

static gboolean
nb_noteview_cb_drag_drop (GtkWidget * widget, GdkDragContext * context, gint x, gint y, guint time, gpointer user_data)
{
	extern NbNotebook * notebook;

	g_print ("drop at %d:%d, index:%d\n", x, y, notebook->dragged_row_index);
	nb_noteview_set_tag_at_coord (notebook->ui->noteview, notebook->ui->noteview->note_link, x, y);

	return TRUE;
}

static void
nb_noteview_set_tag_at_coord (NbNoteview * self, GtkTextTag * tag, gint x, gint y)
{
	GtkTextIter start, end;
	GtkTextBuffer * buffer = gtk_text_view_get_buffer ( GTK_TEXT_VIEW (self->textview) );
	gtk_text_buffer_get_iter_at_offset (buffer, &start, 1);
	gtk_text_buffer_get_iter_at_offset (buffer, &end, 5);
	gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
}
