/*
 *  Copyright (C) 2004-2005 Mathias Andre <mathias.andre@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef NB_TREEVIEW_H
#define NB_TREEVIEW_H

#include <glib-object.h>
#include <gtk/gtk.h>

#include "nb_note.h"

#define NB_TYPE_TREEVIEW           (nb_treeview_get_type ())
#define NB_TREEVIEW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), NB_TYPE_TREEVIEW, NbTreeview))
#define NB_TREEVIEW_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), NB_TYPE_TREEVIEW, NbTreeviewClass))
#define NB_IS_TREEVIEW(obj)        (G_TYPE_CHECK_TYPE ((obj), NB_TYPE_TREEVIEW))
#define NB_IS_TREEVIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NB_TYPE_TREEVIEW))
#define NB_TREEVIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NB_TYPE_TREEVIEW, NbTreeviewClass))

enum
{
	ATTACHMENT_COLUMN,
	TITLE_COLUMN,
	TYPE_COLUMN,
	CREATION_DATE_COLUMN,
	LAST_UPDATE_COLUMN,
	NOTE_POINTER_COLUMN,
	N_COLUMNS
};

static GtkTargetEntry target_list [] = {
	{ "INTEGER", GTK_TARGET_SAME_APP, 0 }
};


typedef struct _RowQueryList RowQueryList;

struct _RowQueryList
{
	gchar * query;
	GList * rr_list;
};

typedef struct _NbTreeview NbTreeview;
typedef struct _NbTreeviewClass NbTreeviewClass;

struct _NbTreeview 
{
	GObject parent;

	/* instance members */
	GtkWidget * tree;
	GtkListStore * store;
	gboolean dispose_has_run;
};

struct _NbTreeviewClass
{
	GObjectClass parent;

	/* class members */
};

GType wl_treeview_get_type (void);

NbTreeview * 		nb_treeview_new (GObject * interface);

/* methods */
GtkTreeIter *		nb_treeview_add_note (NbTreeview * self, NbNote * n, gboolean scroll);
void			nb_treeview_update_note (NbTreeview * self, NbNote * n);
void			nb_treeview_update_attachment_icon (NbTreeview * self, NbNote * n);
GtkTreeSelection *	nb_treeview_get_selection (NbTreeview * self);
void			nb_treeview_remove_note_list (NbTreeview * self, GList * rr_list);
void			nb_treeview_update_with_query (NbTreeview * self, gchar * query);

/* callbacks */
void			nb_treeview_cb_selection_changed (GtkTreeSelection * selection, gpointer user_data);

#endif
